@@ -1,5 +1,3 @@
-package org.apache.maven.shared.scriptinterpreter;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -18,25 +16,27 @@ package org.apache.maven.shared.scriptinterpreter;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.shared.scriptinterpreter;
 
 import java.io.PrintStream;
 
 /**
+ * <p>ExecutionLogger interface.</p>
+ *
  * @author Olivier Lamy
  */
-public interface ExecutionLogger
-{
+public interface ExecutionLogger {
     /**
-     * The stream which will catch the output of the {@link ScriptRunner}.
-     * 
+     * The stream which will catch the output of the {@link org.apache.maven.shared.scriptinterpreter.ScriptRunner}.
+     *
      * @return the output stream
      */
     PrintStream getPrintStream();
 
     /**
      * Consume logging from this component.
-     * 
+     *
      * @param line the line to consume
      */
-    void consumeLine( String line );
+    void consumeLine(String line);
 }
